@@ -6,7 +6,7 @@
 
 package Forks::Super::Job;
 use Forks::Super::Debug qw(debug);
-use Forks::Super::Util qw(is_number qualify_sub_name
+use Forks::Super::Util qw(is_number qualify_sub_name shquote
                           IS_CYGWIN IS_WIN32 is_pipe);
 use Forks::Super::Config qw(:all);
 use Forks::Super::Job::Ipc;   # does windows prefer to load Ipc before Timeout?
@@ -26,7 +26,7 @@ use warnings;
 our @ISA = qw(Exporter);
 our @EXPORT = qw(@ALL_JOBS %ALL_JOBS PREFORK POSTFORK 
                  POSTFORK_PARENT POSTFORK_CHILD);
-our $VERSION = '0.87';
+our $VERSION = '0.88';
 
 our (@ALL_JOBS, %ALL_JOBS, @ARCHIVED_JOBS, $WIN32_PROC, $WIN32_PROC_PID);
 our $OVERLOAD_ENABLED = 0;
@@ -270,7 +270,7 @@ sub toShortString {
 
     my @output;
     foreach my $attr (@to_display) {
-	if (ref $job->{$attr} eq 'ARRAY') {
+	if (ref($job->{$attr}) eq 'ARRAY') {
 	    push @output, "$attr=[" . join(',', @{$job->{$attr}}) . ']';
 	} else {
 	    push @output, "$attr=" . $job->{$attr};
@@ -1094,9 +1094,6 @@ sub _postlaunch_child_to_cmd {
     }
 }
 
-#
-# experimental and undocumented 
-#
 sub _postlaunch_child_to_remote_cmd {
     my $job = shift;
     my $remote = $job->{remote};
@@ -1107,11 +1104,30 @@ sub _postlaunch_child_to_remote_cmd {
     my $retries = $job->{retries} || 0;
     my $this_pid = $$;
 
-    if (!defined($remote->{proto}) || $remote->{proto} eq 'ssh') {
-        if (CONFIG_module('Net::OpenSSH')) {
-            my (%opts,%runopts);
+    if (ref($remote) eq 'ARRAY') {
+        $remote = $remote->[0];
+    }
 
-            my $host = $remote->{host};
+    if (!defined($remote->{proto}) || $remote->{proto} eq 'ssh') {
+        my (%opts,%runopts);
+
+        my $host = $remote->{host};
+
+        my $stdin;
+        if ($job->{stdin}) {
+            if ('ARRAY' eq ref $job->{stdin}) {
+                $stdin = join '', $job->{stdin}; # or join "\n",... ?
+            } else {
+                $stdin = $job->{stdin};
+            }
+        } elsif ($job->{fh_config}{in}) {
+            $stdin = join '', <STDIN>;
+        }
+
+        untie *STDIN;
+        open STDIN,"<",&Forks::Super::Util::DEVNULL;
+
+        if (CONFIG_module('Net::OpenSSH')) {
             foreach my $remoteopt (grep exists $remote->{$_},
                                    qw(key_path user password passphrase
                                       gateway ssh_cmd ctl_dir remote_shell
@@ -1121,19 +1137,6 @@ sub _postlaunch_child_to_remote_cmd {
                 $opts{$remoteopt} = $remote->{$remoteopt};
             }
 
-            my $stdin;
-            if ($job->{stdin}) {
-                if ('ARRAY' eq ref $job->{stdin}) {
-                    $stdin = join '', $job->{stdin}; # or join "\n",... ?
-                } else {
-                    $stdin = $job->{stdin};
-                }
-            } elsif ($job->{fh_config}{in}) {
-                $stdin = join '', <STDIN>;
-            }
-
-            untie *STDIN;
-            open STDIN,"<",&Forks::Super::Util::DEVNULL;
             my $ssh = Net::OpenSSH->new($host,%opts);
             croak $ssh->error if $ssh->error;
             $job->set_signal_pid($ssh->get_master_pid);
@@ -1151,6 +1154,23 @@ sub _postlaunch_child_to_remote_cmd {
             $ssh->disconnect;
             deinit_child();
             exit $rc >> 8;
+        } elsif (Forks::Super::Config::CONFIG_external_program("ssh")) {
+            # poor man's ssh. Not really recommended if
+            # Net::OpenSSH is available.
+            if ($remote->{password}) {
+                deinit_child();
+                die "passphrase with ssh not supported with Net::OpenSSH!";
+            }
+            my $cmd = __build_ssh_command($host, $remote, $job);
+            my $sshpid = CORE::fork();
+            if ($sshpid == 0) {
+                exec($cmd);
+            }
+            $job->set_signal_pid($$);
+            my $waitpid = CORE::waitpid $sshpid,0;
+            my $rc = $?;
+            deinit_child();
+            exit $rc >> 8;
         } else {
             deinit_child();
             carp "Alternate ssh support for remote option not implemented";
@@ -1163,6 +1183,114 @@ sub _postlaunch_child_to_remote_cmd {
     }
 }
 
+sub shquote2 {
+    my $input = shift;
+    return shquote(shquote($input));
+}
+
+sub __build_ssh_command {
+    # poor man's ssh command. Build command line instruction to
+    # run ssh command and capture output. Not the way to do it
+    # if there is any other way to do it.
+    #
+    # we ass-u-me that local host and remote host are POSIX-y,
+    # and that shquote should be applied for both purposes
+    # (so it is applied twice for the actual remote command and
+    # its arguments).
+    
+    my ($host, $remote, $job) = @_;
+
+    my @cmd = (shquote(Forks::Super::Config::CONFIG_external_program("ssh")));
+
+    if ($remote->{debug}) {
+        push @cmd, "-v";
+    }
+
+    my $id = $remote->{identity_file} || $remote->{identity}
+                                      || $remote->{key_path};
+    if ($id && ref($id) eq '') {
+        $id = [ $id ];
+    }
+    if ($id) {
+        push @cmd, "-i", shquote($_) for @$id;
+    }
+
+    if ($remote->{port}) {
+        push @cmd, "-p", shquote($remote->{port});
+    }
+
+    if ($remote->{user}) {
+        my $user = $remote->{user};
+        if ($remote->{password}) {
+            # I don't think this will work ...
+            $user .= ":" . $remote->{password};
+        }
+        push @cmd, "-l", shquote($user);
+    }
+
+    if ($remote->{options}) {
+        my $options = $remote->{options};
+        if (ref($options) eq '') {
+            $options = [ $options ];
+        }
+        push @cmd, "-o", shquote($_) for @$options;
+    }
+
+    push @cmd, shquote($host);
+
+    # command must immediately follow $host
+    # command to remote host must be shell quoted twice!
+    # once for the local shell running ssh, and
+    # once for the remote shell interpreting the command
+
+    if (@{$job->{cmd}} <= 1) {
+        push @cmd, map { shquote2($_) } @{$job->{cmd}};
+    } else {
+        push @cmd, map { shquote2($_) } @{$job->{cmd}};
+    }
+
+    my $stdin;
+    if ($job->{stdin}) {
+        if ('ARRAY' eq ref $job->{stdin}) {
+            $stdin = join '', $job->{stdin}; # or join "\n",... ?
+        } else {
+            $stdin = $job->{stdin};
+        }
+    } elsif ($job->{fh_config}{in}) {
+        $stdin = join '', <STDIN>;
+    }
+    if (defined($stdin)) {
+        open my $fh,'>',$job->{fh_config}{f_in};
+        print $fh $stdin;
+        close $fh;
+        close STDIN;
+        push @cmd, "<" . shquote($job->{fh_config}{f_in});
+    } else {
+        push @cmd, '</dev/null';
+    }
+
+    if ($job->{fh_config}{out}) {
+        close STDOUT;
+        push @cmd, ">" . shquote($job->{fh_config}{f_out});
+    } else {
+        push @cmd, ">/dev/null";
+    }
+    if ($job->{fh_config}{join}) {
+        close STDERR;
+        push @cmd, "2>&1";
+    } elsif ($job->{fh_config}{err}) {
+        close STDERR;
+        push @cmd, "2>" . shquote($job->{fh_config}{f_err});
+    } else {
+        push @cmd, "2>/dev/null";
+    }
+
+#    push @cmd, '>/tmp/ssh.stdout';
+#    push @cmd, '2>/tmp/ssh.stderr';
+
+    return "@cmd";
+}
+
 sub _postlaunch_child_to_sub {
     my $job = shift;
     my $sub = $job->{sub};
@@ -1524,7 +1652,6 @@ sub _resume_daemon {
 sub terminate {
     my $j = shift;
     if (!ref($j) || !$j->isa('Forks::Super::Job')) {
-#   if (ref $j ne 'Forks::Super::Job') {
 	$j = Forks::Super::Job::get($j);
     }
     if (&IS_CYGWIN) {
@@ -1879,7 +2006,6 @@ sub _resolve_names {
     my @out = ();
     foreach my $id (@{$id_list}) {
 	if (ref($id) && $id->isa('Forks::Super::Job')) {
-	#if (ref $id eq 'Forks::Super::Job') {
 	    push @out, $id;
 	} elsif (is_number($id) && defined($ALL_JOBS{$id})) {
 	    push @out, $id;
@@ -2071,7 +2197,7 @@ sub enable_overload {
     if (!$OVERLOAD_ENABLED) {
 	$OVERLOAD_ENABLED = 1;
 
-	if (!eval {
+	if (!eval  q!
 	    # in most contexts a Forks::Super::Job obj acts like its process id
 	    use overload
 		'""' => sub { $_[0]->{pid} },
@@ -2122,7 +2248,7 @@ sub enable_overload {
 	    *{__PACKAGE__ . '::(<>'} = sub { $_[0]->read_stdout() };
 
 
-	    1 }            # end eval { use overload ... }
+	    1 !            # end eval 'use overload ...'
 	    ) {
 	    carp 'Error enabling overloading on ',
 	    	"Forks::Super::Job objects: $@\n";
@@ -2159,7 +2285,6 @@ sub get {
 	Carp::cluck 'undef value passed to Forks::Super::Job::get()';
     }
     if (ref($id) && $id->isa('Forks::Super::Job')) {
-#    if (ref $id eq 'Forks::Super::Job') {
 	return $id;
     }
     if (defined $ALL_JOBS{$id}) {
@@ -2217,7 +2342,6 @@ sub getOrMock {
 # retrieve a job object for a pid or job name, if necessary
 sub _resolve {
     if (!ref($_[0]) || !$_[0]->isa('Forks::Super::Job')) {
-#   if (ref $_[0] ne 'Forks::Super::Job') {
 	my $job = get($_[0]);
 	if (defined $job) {
 	    return $_[0] = $job;
@@ -2453,7 +2577,7 @@ Forks::Super::Job - object representing a background task
 
 =head1 VERSION
 
-0.87
+0.88
 
 =head1 SYNOPSIS
 
@@ -3243,7 +3367,7 @@ Marty O'Brien, E<lt>mob@cpan.orgE<gt>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (c) 2009-2016, Marty O'Brien.
+Copyright (c) 2009-2017, Marty O'Brien.
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself, either Perl version 5.8.8 or,
