@@ -33,7 +33,7 @@ $| = 1;
 
 our @ISA = qw(Exporter);
 our @EXPORT = qw(close_fh);
-our $VERSION = '0.87';
+our $VERSION = '0.88';
 our $NO_README = 0;
 
 our (%FILENO, %SIG_OLD, $IPC_COUNT, $IPC_DIR_DEDICATED,
@@ -541,6 +541,7 @@ sub _preconfig_fh_parse_stdxxx {
 	} else {
 	    $config->{stdin} = $job->{stdin};
 	}
+        $config->{scalar}{in} = 1;
     }
 
     if (defined $job->{stdout}) {
@@ -549,6 +550,7 @@ sub _preconfig_fh_parse_stdxxx {
 		    "'stdout' option must be a SCALAR ref\n";
 	} else {
 	    $config->{stdout} = $job->{stdout};
+            $config->{scalar}{out} = 1;
 	    $config->{out} = 1;
 	    $job->{'_callback_collect'} =
                 \&Forks::Super::Job::Ipc::collect_output;
@@ -562,6 +564,7 @@ sub _preconfig_fh_parse_stdxxx {
 	} else {
 	    $config->{stderr} = $job->{stderr};
 	    $config->{err} = 1;
+            $config->{scalar}{err} = 1;
 	    $job->{'_callback_collect'} =
                 \&Forks::Super::Job::Ipc::collect_output;
 	}
@@ -3378,7 +3381,7 @@ Forks::Super::Job::Ipc - interprocess communication routines for Forks::Super
 
 =head1 VERSION
 
-0.87
+0.88
 
 =head1 DESCRIPTION
 
@@ -3396,7 +3399,7 @@ Marty O'Brien, E<lt>mob@cpan.orgE<gt>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (c) 2009-2016, Marty O'Brien.
+Copyright (c) 2009-2017, Marty O'Brien.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.8 or,
