@@ -18,7 +18,7 @@ use warnings;
 use constant FOREVER => 9E9;
 use constant LONG_TIME => 9E8;
 
-our $VERSION = '0.87';
+our $VERSION = '0.88';
 
 our $MAIN_PID = $$;
 our $DISABLE_INT = 0;
@@ -191,8 +191,8 @@ sub _child_timeout {
     # we wish to kill not only this child process,
     # but any other active processes that it has spawned.
     # There are several ways to do this.
-    if (Forks::Super::Config::CONFIG('Proc::ProcessTable') &&
-	$Forks::Super::SysInfo::PROC_PROCESSTABLE_OK) {
+    if ($Forks::Super::SysInfo::PROC_PROCESSTABLE_OK &&
+        Forks::Super::Config::CONFIG('Proc::ProcessTable')) {
 	my @to_kill = 
 	    _child_timeout_read_procs_to_kill_from_Proc_ProcessTable();
 	if (defined $Forks::Super::Job::CHILD_EXEC_PID) {
