@@ -16,8 +16,8 @@ use constant IS_CYGWIN => $^O =~ /cygwin/i;
 use constant IS_WIN32ish => &IS_WIN32 || &IS_CYGWIN;
 
 our @ISA = qw(Exporter);
-our $VERSION = '0.87';
-our @EXPORT_OK = qw(Ctime is_number isValidPid pause qualify_sub_name 
+our $VERSION = '0.88';
+our @EXPORT_OK = qw(Ctime is_number isValidPid pause qualify_sub_name shquote
 		    is_socket is_pipe IS_WIN32 IS_CYGWIN okl DEVNULL DEVTTY);
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
 
@@ -27,7 +27,7 @@ our $_PAUSE = 0;
 our $DEFAULT_PAUSE = 0.10; # s. Warning: may also be set in Forks/Super.pm
 our $DEFAULT_PAUSE_IO = 0.05;
 
-$Time_HiRes_avail = eval  { use Time::HiRes; 1 } || 0;
+$Time_HiRes_avail = eval  'use Time::HiRes; 1' || 0;
 if (!$Time_HiRes_avail) {
     *Time::HiRes::time = \&time;
     *Time::HiRes::sleep = \&__fake_Time_HiRes_sleep;
@@ -86,7 +86,6 @@ sub isValidPid {
     my ($pid, $is_wait) = @_;
 
     if (ref($pid) && $pid->isa('Forks::Super::Job')) {
-#   if (ref $pid eq 'Forks::Super::Job') {
 	# DWIM - if the job is completed, isValidPid() was probably called from
 	#    the output of a waitpid/wait call, so test {real_pid} and not {pid}
 	#    DWIM behavior can be overridden with $is_wait argument.
@@ -340,6 +339,27 @@ sub filter (&\@) {
     return @$out;
 }
 
+# shell quote for a single command-line argument on POSIX shells
+sub shquote {  # borrowed heavily from String::ShellQuote 1.04
+    local $_ = shift;
+    return q{''} if !defined($_) || $_ eq '';
+    s/\x00//g;   # no way to quote null bytes?
+    if (m|[^\w!%+,\-./:=@^]|) {
+        s/'/'\\''/g;
+        s|((?:'\\''){2,})|q{'"} . (q{'} x (length($1) / 4)) . q{"'}|ge;
+        $_ = qq{'$_'};
+        s/^''//;
+        s/''$//;
+    }
+    return $_;
+}
+
+# shell quote for a single command-line argument on MSWin32 cmd shell
+sub cmdquote {
+    # TODO
+    @_;
+}
+
 sub okl {
     # pass a unit test automatically if $ENV{TEST_LENIENT} is set.
     # Use in special circumstances (e.g. high CPU load, flaky network)
@@ -374,7 +394,7 @@ Forks::Super::Util - utility routines for Forks::Super module
 
 =head1 VERSION
 
-0.87
+0.88
 
 =head1 SYNOPSIS
 
@@ -540,7 +560,7 @@ Marty O'Brien, E<lt>mob@cpan.orgE<gt>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (c) 2009-2016, Marty O'Brien.
+Copyright (c) 2009-2017, Marty O'Brien.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.8 or,
