@@ -51,7 +51,7 @@ use IO::Handle;
 use Getopt::Long;
 use POSIX ':sys_wait_h';
 
-eval { use Time::HiRes; 1 }
+eval 'use Time::HiRes; 1'
     or do { *Time::HiRes::time = sub { time } };
 $| = 1;
 
@@ -81,7 +81,7 @@ my @perl_opts = ();
 my @env = ();
 my $maxproc = &maxproc_initial;
 my $use_color = $ENV{COLOR} && -t STDOUT &&
-    eval { use Term::ANSIColor; $Term::ANSIColor::VERSION >= 3.00 };
+    eval 'use Term::ANSIColor; $Term::ANSIColor::VERSION >= 3.00';
 my $timeout = $ENV{TEST_TIMEOUT} || 150;
 my $repeat = 1;
 my $xrepeat = 1;
@@ -97,6 +97,7 @@ my $use_socket = '';
 my $help = '';
 my $pause = 0;
 my $inorder = 0;
+my $ssh_test = $ENV{TEST_SSH};
 $::fail35584 = '';
 
 # [-h] [-c] [-v] [-I lib [-I lib [...]]] [-p xxx [-p xxx [...]]] [-s]
@@ -104,25 +105,25 @@ $::fail35584 = '';
 # abcdefghijklmnopqrstuvwxyz
 # x s @  x@   i x@xixi x i x
 my $result = GetOptions(
-    'h|harness' => \$use_harness,
-    'C|color'   => \$use_color,
-    'verbose'   => \$test_verbose,
-    'include=s' => \@use_libs,
-    'p|popts=s' => \@perl_opts,
-    'env=s'     => \@env,
-    's|shuffle' => \$shuffle,
-    'timeout=i' => \$timeout,
-    'r|repeat=i' => \$repeat,
-    'xrepeat=i' => \$xrepeat,
-    'maxproc=i' => \$maxproc,
-    'q|quiet'   => \$quiet,
+    'h|harness'   => \$use_harness,
+    'C|color'     => \$use_color,
+    'verbose'     => \$test_verbose,
+    'include=s'   => \@use_libs,
+    'p|popts=s'   => \@perl_opts,
+    'env=s'       => \@env,
+    's|shuffle'   => \$shuffle,
+    't|timeout=i' => \$timeout,
+    'r|repeat=i'  => \$repeat,
+    'xrepeat=i'   => \$xrepeat,
+    'maxproc=i'   => \$maxproc,
+    'q|quiet'     => \$quiet,
     'qq|really-quiet' => \$really_quiet,
-    'debug'     => \$debug,
-    'z|socket'  => \$use_socket,
+    'debug'       => \$debug,
+    'z|socket'    => \$use_socket,
     'abort-on-fail' => \$abort_on_first_error,
-    'pause=s'   => \$pause,
-    'O|order'   => \$inorder,
-    'help'      => \$help,
+    'pause=s'     => \$pause,
+    'O|order'    => \$inorder,
+    'help'       => \$help,
     );
 
 if ($help) {
@@ -230,6 +231,46 @@ sub main {
 	die "No tests specified.\n";
     }
 
+    my $sshd;
+
+    if ($ssh_test) {
+        print STDERR "Trying to identify or create test ssh server ...\n";
+        Forks::Super::POSTFORK_CHILD {
+            *Test::SSH::Backend::OpenSSH::_run_dir = sub { };
+        };
+
+        # first, try public key authentication for the current user and host
+        my $userathost = $ENV{USER} . '@' . $ENV{HOSTNAME};
+        my $ssh = Forks::Super::Config::CONFIG_external_program("ssh");
+        if ($ssh && $userathost =~ /.@./) {
+            my @cmds = ("true", "echo", "dir");
+            foreach my $cmd (@cmds) {
+                local $SIG{ALRM} = sub { die "ssh timeout $$ $0 @ARGV\n"; };
+                alarm 15;
+                if (eval {my $c1=system($ssh, $userathost, $cmd);$c1==0}) {
+                    $ENV{TEST_SSH_TARGET} = "ssh://$userathost";
+                    print STDERR
+                        "... publickey on current user,host works!\n";
+                    last;
+                }
+                alarm 0;
+            }
+        }
+
+        # second, let Test::SSH try to find a server or set one up
+        if (!$ENV{TEST_SSH_TARGET}) {
+            my $main_pid = $$;
+            if (eval "use Test::SSH;1") {
+                my %opts = (logger => sub {}, timeout => 600);
+                $sshd = eval { Test::SSH->new(%opts) };
+                if ($sshd) {
+                    $ENV{TEST_SSH_TARGET} = $sshd->uri;
+                    print STDERR "... Test::SSH uri: $ENV{TEST_SSH_TARGET}\n";
+                }
+            }
+        }
+    }
+
     for ($iteration = 1; $iteration <= $repeat; $iteration++) {
 	color_print ITERATION => "Iteration #$iteration/$repeat\n" if $repeat>1;
 	if ($iteration > 1) {
@@ -826,7 +867,7 @@ forked_harness.pl - run tests in parallel with Forks::Super
 
 =head1 VERSION
 
-0.87
+0.88
 
 =head1 SYNOPSIS
 
@@ -1178,7 +1219,7 @@ Marty O'Brien, E<lt>mob@cpan.orgE<gt>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (c) 2010-2016, Marty O'Brien.
+Copyright (c) 2010-2017, Marty O'Brien.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.8 or,
